@@ -69,10 +69,16 @@ class EditMode:
         return None, None, candidates
 
     def _on_str(self, wnd, s):
+        if not wnd.document.mode.DELAY_STR:
+            self.flush_pending_str(wnd)
+
         for c in s:
             if c in '\t\r\n' or c >= ' ':
                 self.pending_str += c
 
+                if not wnd.document.mode.DELAY_STR:
+                    self.flush_pending_str(wnd)
+
     def _keys_to_str(self, keys):
         ret = []
         alt = False
@@ -103,6 +109,10 @@ class EditMode:
             msg = ' '.join(cur) + ' [%s]' % (', '.join(sorted(nextkeys)))
             kaa.app.messagebar.set_message(msg)
 
+    def on_non_command_str(self, wnd, event, s):
+        self._on_str(wnd, s)
+        del self.last_command_keys[:]
+
     def on_key_pressed(self, wnd, event):
         s, commands, candidate = self._get_command(wnd, event)
         s, commands, candidate = wnd.document.mode.on_keypressed(
@@ -111,8 +121,7 @@ class EditMode:
         self._show_pending_keys(s, commands, candidate)
         try:
             if s:
-                self._on_str(wnd, s)
-                del self.last_command_keys[:]
+                self.on_non_command_str(wnd, event, s)
 
             elif commands:
                 self.flush_pending_str(wnd)
@@ -183,6 +192,16 @@ class ReplaceMode(EditMode):
 class CommandMode(EditMode):
     MODENAME = 'Command'
 
+    def on_non_command_str(self, wnd, event, s):
+        is_available, command = wnd.document.mode.get_command(
+                                    'editmode.insert')
+        if command:
+            self.flush_pending_str(wnd)
+            command(wnd)
+            wnd.document.mode.on_str(wnd, s, False)
+        else:
+            super().on_non_command_str(wnd, event, s)
+
     def on_key_pressed(self, wnd, event):
         # check if key is repeat count
         if not self.pending_keys:
