@@ -21,14 +21,22 @@ class Theme:
 
     def update(self, rhs):
         default = self.styles.get('default', None)
-        self.add_styles(s.copy() for s in rhs)
+        styles = []
+        for s in rhs:
+            s = s.copy()
+            if s.name == 'default':
+                s.set_default_attr(default)
+            styles.append(s)
+        self.add_styles(styles)
 
     def finish_update(self):
         default = self.styles.get('default', None)
         for style in self.styles.values():
             style.set_default_attr(default)
 
+
 class Style:
+
     def __init__(self, name, fgcolor, bgcolor, underline=False,
                  bold=False, nowrap=False, rjust=False):
         self.name = name
