@@ -217,7 +217,7 @@ class PythonDebuggerPanel(dialogmode.DialogMode):
         super().close()
         self.port = None
 
-    def on_str(self, wnd, s):
+    def on_str(self, wnd, s, overwrite=False):
         pass
 
     def build(self, stack):
@@ -387,8 +387,7 @@ class PythonDebuggerPanel(dialogmode.DialogMode):
 
 
 def show_callstack(port, stack):
-    buf = document.Buffer()
-    doc = document.Document(buf)
+    doc = document.Document()
     doc.set_title('Python call stack')
     mode = PythonDebuggerPanel()
     mode.port = port
@@ -399,8 +398,7 @@ def show_callstack(port, stack):
     dlg = kaa.app.show_inputline(doc)
     ret = dlg.get_label('editor')
 
-    buf = document.Buffer()
-    stacklist = document.Document(buf)
+    stacklist = document.Document()
     stacklistmode = PythonStackList()
     stacklist.setmode(stacklistmode)
     stacklistmode.build(stack)
